@@ -18,10 +18,12 @@ __all__ = [
     "testing",
     "detection",
     "query",
+    "schema",
 ]
 
 from . import (
     testing,
     detection,
     query,
+    schema,
 )
