@@ -23,10 +23,6 @@ __all__ = [
     "DataModelMapping",
     "DataModel",
     "DataModelOverrides",
-    "LogTypeApacheAccessCommon",
-    "LogTypeApacheAccessCombined",
-    "LogTypeAsanaAudit",
-    "LogTypeAtlassianAudit",
     "LogTypeAWSALB",
     "LogTypeAWSAuroraMySQLAudit",
     "LogTypeAWSCloudTrail",
@@ -34,45 +30,76 @@ __all__ = [
     "LogTypeAWSCloudTrailInsight",
     "LogTypeAWSCloudWatchEvents",
     "LogTypeAWSConfig",
-    "LogTypeAmazonEKSAudit",
-    "LogTypeAmazonEKSAuthenticator",
     "LogTypeAWSGuardDuty",
     "LogTypeAWSS3ServerAccess",
     "LogTypeAWSTransitGatewayFlow",
     "LogTypeAWSVPCDns",
     "LogTypeAWSVPCFlow",
     "LogTypeAWSWAFWebACL",
+    "LogTypeAlphaSOCAlert",
+    "LogTypeAmazonEKSAudit",
+    "LogTypeAmazonEKSAuthenticator",
+    "LogTypeApacheAccessCombined",
+    "LogTypeApacheAccessCommon",
+    "LogTypeAsanaAudit",
+    "LogTypeAtlassianAudit",
     "LogTypeBitwardenEvents",
     "LogTypeBoxEvent",
-    "LogTypeCiscoUmbrellaDNS",
     "LogTypeCiscoUmbrellaCloudFirewall",
+    "LogTypeCiscoUmbrellaDNS",
     "LogTypeCiscoUmbrellaIP",
     "LogTypeCiscoUmbrellaProxy",
     "LogTypeCloudflareAudit",
+    "LogTypeCloudflareFirewall",
     "LogTypeCloudflareHttpRequest",
     "LogTypeCloudflareSpectrum",
-    "LogTypeCloudflareFirewall",
+    "LogTypeCrowdstrikeAIDMaster",
+    "LogTypeCrowdstrikeActivityAudit",
+    "LogTypeCrowdstrikeAppInfo",
+    "LogTypeCrowdstrikeCriticalFile",
+    "LogTypeCrowdstrikeDNSRequest",
+    "LogTypeCrowdstrikeDetectionSummary",
     "LogTypeCrowdstrikeFDREvent",
+    "LogTypeCrowdstrikeGroupIdentity",
+    "LogTypeCrowdstrikeManagedAssets",
+    "LogTypeCrowdstrikeNetworkConnect",
+    "LogTypeCrowdstrikeNetworkListen",
+    "LogTypeCrowdstrikeNotManagedAssets",
+    "LogTypeCrowdstrikeProcessRollup2",
+    "LogTypeCrowdstrikeProcessRollup2Stats",
+    "LogTypeCrowdstrikeSyntheticProcessRollup2",
+    "LogTypeCrowdstrikeUnknown",
+    "LogTypeCrowdstrikeUserIdentity",
+    "LogTypeCrowdstrikeUserInfo",
+    "LogTypeCrowdstrikeUserLogonLogoff",
     "LogTypeDropboxTeamEvent",
-    "LogTypeDuoAuthentication",
     "LogTypeDuoAdministrator",
-    "LogTypeDuoTelephony",
+    "LogTypeDuoAuthentication",
     "LogTypeDuoOfflineEnrollment",
+    "LogTypeDuoTelephony",
     "LogTypeFastlyAccess",
     "LogTypeFluentdSyslog3164",
     "LogTypeFluentdSyslog5424",
-    "LogTypeGSuiteReports",
-    "LogTypeGSuiteActivityEvent",
     "LogTypeGCPAuditLog",
     "LogTypeGCPHTTPLoadBalancer",
-    "LogTypeGitHubAudit",
+    "LogTypeGSuiteActivityEvent",
+    "LogTypeGSuiteReports",
     "LogTypeGitHubAudit",
     "LogTypeGitLabAPI",
     "LogTypeGitLabAudit",
     "LogTypeGitLabExceptions",
-    "LogTypeGitLabIntegrations",
     "LogTypeGitLabGit",
+    "LogTypeGitLabIntegrations",
     "LogTypeGitLabProduction",
+    "LogTypeGravitationalTeleportAudit",
+    "LogTypeGreyNoiseNoise",
+    "LogTypeGreyNoiseRIOT",
+    "LogTypeIPInfoASNCIDR",
+    "LogTypeIPInfoASNRanges",
+    "LogTypeIPInfoLocationCIDR",
+    "LogTypeIPInfoLocationRanges",
+    "LogTypeIPInfoPrivacyCIDR",
+    "LogTypeIPInfoPrivacyRanges",
     "LogTypeJamfproLogin",
     "LogTypeJuniperAccess",
     "LogTypeJuniperAudit",
@@ -80,39 +107,41 @@ __all__ = [
     "LogTypeJuniperMWS",
     "LogTypeJuniperPostgres",
     "LogTypeJuniperSecurity",
-    "LogTypeLaceworkEvents",
+    "LogTypeLaceworkAgentManagement",
     "LogTypeLaceworkAlertDetails",
+    "LogTypeLaceworkAllFiles",
     "LogTypeLaceworkApplications",
+    "LogTypeLaceworkChangeFiles",
     "LogTypeLaceworkCloudCompliance",
     "LogTypeLaceworkCloudConfiguration",
-    "LogTypeLaceworkAgentManagement",
-    "LogTypeLaceworkAllFiles",
-    "LogTypeLaceworkChangeFiles",
     "LogTypeLaceworkCmdline",
     "LogTypeLaceworkConnections",
     "LogTypeLaceworkContainerSummary",
     "LogTypeLaceworkContainerVulnDetails",
     "LogTypeLaceworkDNSQuery",
+    "LogTypeLaceworkEvents",
     "LogTypeLaceworkHostVulnDetails",
     "LogTypeLaceworkImage",
     "LogTypeLaceworkInterfaces",
     "LogTypeLaceworkInternalIPA",
     "LogTypeLaceworkMachineDetails",
     "LogTypeLaceworkMachineSummary",
+    "LogTypeLaceworkNewHashes",
     "LogTypeLaceworkPackage",
     "LogTypeLaceworkPodSummary",
     "LogTypeLaceworkProcessSummary",
     "LogTypeLaceworkUserDetails",
     "LogTypeLaceworkUserLogin",
-    "LogTypeMicrosoft365AuditExchange",
-    "LogTypeMicrosoft365AuditSharePoint",
-    "LogTypeMicrosoft365AuditGeneral",
-    "LogTypeMicrosoft365DLPAll",
     "LogTypeMicrosoft365AuditAzureActiveDirectory",
+    "LogTypeMicrosoft365AuditExchange",
+    "LogTypeMicrosoft365AuditGeneral",
+    "LogTypeMicrosoft365AuditSharePoint",
+    "LogTypeMicrosoft365DLPAll",
     "LogTypeMicrosoftGraphSecurityAlert",
     "LogTypeMongoDBOrganizationEvent",
     "LogTypeMongoDBProjectEvent",
     "LogTypeNginxAccess",
+    "LogTypeOSSECEventInfo",
     "LogTypeOktaSystemLog",
     "LogTypeOneLoginEvents",
     "LogTypeOnePasswordItemUsage",
@@ -121,7 +150,7 @@ __all__ = [
     "LogTypeOsqueryDifferential",
     "LogTypeOsquerySnapshot",
     "LogTypeOsqueryStatus",
-    "LogTypeOSSECEventInfo",
+    "LogTypePantherAudit",
     "LogTypeSalesforceLogin",
     "LogTypeSalesforceLoginAs",
     "LogTypeSalesforceLogout",
@@ -129,48 +158,51 @@ __all__ = [
     "LogTypeSentinelOneActivity",
     "LogTypeSentinelOneDeepVisibility",
     "LogTypeSentinelOneDeepVisibilityV2",
-    "LogTypeSlackAuditLogs",
     "LogTypeSlackAccessLogs",
+    "LogTypeSlackAuditLogs",
     "LogTypeSlackIntegrationLogs",
     "LogTypeSnykGroupAudit",
     "LogTypeSnykOrgAudit",
     "LogTypeSophosCentral",
-    "LogTypeSuricataDNS",
+    "LogTypeSuricataAlert",
     "LogTypeSuricataAnomaly",
+    "LogTypeSuricataDHCP",
+    "LogTypeSuricataDNS",
+    "LogTypeSuricataFileInfo",
+    "LogTypeSuricataFlow",
+    "LogTypeSuricataHTTP",
+    "LogTypeSuricataSSH",
+    "LogTypeSuricataTLS",
     "LogTypeSysdigAudit",
-    "LogTypeSyslogRFC5424",
     "LogTypeSyslogRFC3164",
-    "LogTypeGravitationalTeleportAudit",
+    "LogTypeSyslogRFC5424",
+    "LogTypeTorExitNode",
     "LogTypeWorkdayActivity",
     "LogTypeWorkdaySignOnAttempt",
-    "LogTypeZeekDNS",
     "LogTypeZeekCaptureLoss",
     "LogTypeZeekConn",
     "LogTypeZeekDHCP",
+    "LogTypeZeekDNS",
     "LogTypeZeekDPD",
     "LogTypeZeekFiles",
     "LogTypeZeekHTTP",
-    "LogTypeZeekNotice",
     "LogTypeZeekNTP",
+    "LogTypeZeekNotice",
     "LogTypeZeekOCSP",
     "LogTypeZeekReporter",
-    "LogTypeZeekSsh",
     "LogTypeZeekSoftware",
-    "LogTypeZeekStats",
+    "LogTypeZeekSsh",
     "LogTypeZeekSsl",
-    "LogTypeZeekX509",
+    "LogTypeZeekStats",
     "LogTypeZeekTunnel",
     "LogTypeZeekWeird",
+    "LogTypeZeekX509",
     "LogTypeZendeskAudit",
     "LogTypeZoomActivity",
     "LogTypeZoomOperation",
 ]
 
 
-LogTypeApacheAccessCommon = "Apache.AccessCommon"
-LogTypeApacheAccessCombined = "Apache.AccessCombined"
-LogTypeAsanaAudit = "Asana.Audit"
-LogTypeAtlassianAudit = "Atlassian.Audit"
 LogTypeAWSALB = "AWS.ALB"
 LogTypeAWSAuroraMySQLAudit = "AWS.AuroraMySQLAudit"
 LogTypeAWSCloudTrail = "AWS.CloudTrail"
@@ -178,45 +210,76 @@ LogTypeAWSCloudTrailDigest = "AWS.CloudTrailDigest"
 LogTypeAWSCloudTrailInsight = "AWS.CloudTrailInsight"
 LogTypeAWSCloudWatchEvents = "AWS.CloudWatchEvents"
 LogTypeAWSConfig = "AWS.Config"
-LogTypeAmazonEKSAudit = "Amazon.EKS.Audit"
-LogTypeAmazonEKSAuthenticator = "Amazon.EKS.Authenticator"
 LogTypeAWSGuardDuty = "AWS.GuardDuty"
 LogTypeAWSS3ServerAccess = "AWS.S3ServerAccess"
 LogTypeAWSTransitGatewayFlow = "AWS.TransitGatewayFlow"
 LogTypeAWSVPCDns = "AWS.VPCDns"
 LogTypeAWSVPCFlow = "AWS.VPCFlow"
 LogTypeAWSWAFWebACL = "AWS.WAFWebACL"
+LogTypeAlphaSOCAlert = "AlphaSOC.Alert"
+LogTypeAmazonEKSAudit = "Amazon.EKS.Audit"
+LogTypeAmazonEKSAuthenticator = "Amazon.EKS.Authenticator"
+LogTypeApacheAccessCombined = "Apache.AccessCombined"
+LogTypeApacheAccessCommon = "Apache.AccessCommon"
+LogTypeAsanaAudit = "Asana.Audit"
+LogTypeAtlassianAudit = "Atlassian.Audit"
 LogTypeBitwardenEvents = "Bitwarden.Events"
 LogTypeBoxEvent = "Box.Event"
-LogTypeCiscoUmbrellaDNS = "CiscoUmbrella.DNS"
 LogTypeCiscoUmbrellaCloudFirewall = "CiscoUmbrella.CloudFirewall"
+LogTypeCiscoUmbrellaDNS = "CiscoUmbrella.DNS"
 LogTypeCiscoUmbrellaIP = "CiscoUmbrella.IP"
 LogTypeCiscoUmbrellaProxy = "CiscoUmbrella.Proxy"
 LogTypeCloudflareAudit = "Cloudflare.Audit"
+LogTypeCloudflareFirewall = "Cloudflare.Firewall"
 LogTypeCloudflareHttpRequest = "Cloudflare.HttpRequest"
 LogTypeCloudflareSpectrum = "Cloudflare.Spectrum"
-LogTypeCloudflareFirewall = "Cloudflare.Firewall"
+LogTypeCrowdstrikeAIDMaster = "Crowdstrike.AIDMaster"
+LogTypeCrowdstrikeActivityAudit = "Crowdstrike.ActivityAudit"
+LogTypeCrowdstrikeAppInfo = "Crowdstrike.AppInfo"
+LogTypeCrowdstrikeCriticalFile = "Crowdstrike.CriticalFile"
+LogTypeCrowdstrikeDNSRequest = "Crowdstrike.DNSRequest"
+LogTypeCrowdstrikeDetectionSummary = "Crowdstrike.DetectionSummary"
 LogTypeCrowdstrikeFDREvent = "Crowdstrike.FDREvent"
+LogTypeCrowdstrikeGroupIdentity = "Crowdstrike.GroupIdentity"
+LogTypeCrowdstrikeManagedAssets = "Crowdstrike.ManagedAssets"
+LogTypeCrowdstrikeNetworkConnect = "Crowdstrike.NetworkConnect"
+LogTypeCrowdstrikeNetworkListen = "Crowdstrike.NetworkListen"
+LogTypeCrowdstrikeNotManagedAssets = "Crowdstrike.NotManagedAssets"
+LogTypeCrowdstrikeProcessRollup2 = "Crowdstrike.ProcessRollup2"
+LogTypeCrowdstrikeProcessRollup2Stats = "Crowdstrike.ProcessRollup2Stats"
+LogTypeCrowdstrikeSyntheticProcessRollup2 = "Crowdstrike.SyntheticProcessRollup2"
+LogTypeCrowdstrikeUnknown = "Crowdstrike.Unknown"
+LogTypeCrowdstrikeUserIdentity = "Crowdstrike.UserIdentity"
+LogTypeCrowdstrikeUserInfo = "Crowdstrike.UserInfo"
+LogTypeCrowdstrikeUserLogonLogoff = "Crowdstrike.UserLogonLogoff"
 LogTypeDropboxTeamEvent = "Dropbox.TeamEvent"
-LogTypeDuoAuthentication = "Duo.Authentication"
 LogTypeDuoAdministrator = "Duo.Administrator"
-LogTypeDuoTelephony = "Duo.Telephony"
+LogTypeDuoAuthentication = "Duo.Authentication"
 LogTypeDuoOfflineEnrollment = "Duo.OfflineEnrollment"
+LogTypeDuoTelephony = "Duo.Telephony"
 LogTypeFastlyAccess = "Fastly.Access"
 LogTypeFluentdSyslog3164 = "Fluentd.Syslog3164"
 LogTypeFluentdSyslog5424 = "Fluentd.Syslog5424"
-LogTypeGSuiteReports = "GSuite.Reports"
-LogTypeGSuiteActivityEvent = "GSuite.ActivityEvent"
 LogTypeGCPAuditLog = "GCP.AuditLog"
 LogTypeGCPHTTPLoadBalancer = "GCP.HTTPLoadBalancer"
-LogTypeGitHubAudit = "GitHub.Audit"
+LogTypeGSuiteActivityEvent = "GSuite.ActivityEvent"
+LogTypeGSuiteReports = "GSuite.Reports"
 LogTypeGitHubAudit = "GitHub.Audit"
 LogTypeGitLabAPI = "GitLab.API"
 LogTypeGitLabAudit = "GitLab.Audit"
 LogTypeGitLabExceptions = "GitLab.Exceptions"
-LogTypeGitLabIntegrations = "GitLab.Integrations"
 LogTypeGitLabGit = "GitLab.Git"
+LogTypeGitLabIntegrations = "GitLab.Integrations"
 LogTypeGitLabProduction = "GitLab.Production"
+LogTypeGravitationalTeleportAudit = "Gravitational.TeleportAudit"
+LogTypeGreyNoiseNoise = "GreyNoise.Noise"
+LogTypeGreyNoiseRIOT = "GreyNoise.RIOT"
+LogTypeIPInfoASNCIDR = "IPInfo.ASNCIDR"
+LogTypeIPInfoASNRanges = "IPInfo.ASNRanges"
+LogTypeIPInfoLocationCIDR = "IPInfo.LocationCIDR"
+LogTypeIPInfoLocationRanges = "IPInfo.LocationRanges"
+LogTypeIPInfoPrivacyCIDR = "IPInfo.PrivacyCIDR"
+LogTypeIPInfoPrivacyRanges = "IPInfo.PrivacyRanges"
 LogTypeJamfproLogin = "Jamfpro.Login"
 LogTypeJuniperAccess = "Juniper.Access"
 LogTypeJuniperAudit = "Juniper.Audit"
@@ -224,39 +287,41 @@ LogTypeJuniperFirewall = "Juniper.Firewall"
 LogTypeJuniperMWS = "Juniper.MWS"
 LogTypeJuniperPostgres = "Juniper.Postgres"
 LogTypeJuniperSecurity = "Juniper.Security"
-LogTypeLaceworkEvents = "Lacework.Events"
+LogTypeLaceworkAgentManagement = "Lacework.AgentManagement"
 LogTypeLaceworkAlertDetails = "Lacework.AlertDetails"
+LogTypeLaceworkAllFiles = "Lacework.AllFiles"
 LogTypeLaceworkApplications = "Lacework.Applications"
+LogTypeLaceworkChangeFiles = "Lacework.ChangeFiles"
 LogTypeLaceworkCloudCompliance = "Lacework.CloudCompliance"
 LogTypeLaceworkCloudConfiguration = "Lacework.CloudConfiguration"
-LogTypeLaceworkAgentManagement = "Lacework.AgentManagement"
-LogTypeLaceworkAllFiles = "Lacework.AllFiles"
-LogTypeLaceworkChangeFiles = "Lacework.ChangeFiles"
 LogTypeLaceworkCmdline = "Lacework.Cmdline"
 LogTypeLaceworkConnections = "Lacework.Connections"
 LogTypeLaceworkContainerSummary = "Lacework.ContainerSummary"
 LogTypeLaceworkContainerVulnDetails = "Lacework.ContainerVulnDetails"
 LogTypeLaceworkDNSQuery = "Lacework.DNSQuery"
+LogTypeLaceworkEvents = "Lacework.Events"
 LogTypeLaceworkHostVulnDetails = "Lacework.HostVulnDetails"
 LogTypeLaceworkImage = "Lacework.Image"
 LogTypeLaceworkInterfaces = "Lacework.Interfaces"
 LogTypeLaceworkInternalIPA = "Lacework.InternalIPA"
 LogTypeLaceworkMachineDetails = "Lacework.MachineDetails"
 LogTypeLaceworkMachineSummary = "Lacework.MachineSummary"
+LogTypeLaceworkNewHashes = "Lacework.NewHashes"
 LogTypeLaceworkPackage = "Lacework.Package"
 LogTypeLaceworkPodSummary = "Lacework.PodSummary"
 LogTypeLaceworkProcessSummary = "Lacework.ProcessSummary"
 LogTypeLaceworkUserDetails = "Lacework.UserDetails"
 LogTypeLaceworkUserLogin = "Lacework.UserLogin"
-LogTypeMicrosoft365AuditExchange = "Microsoft365.Audit.Exchange"
-LogTypeMicrosoft365AuditSharePoint = "Microsoft365.Audit.SharePoint"
-LogTypeMicrosoft365AuditGeneral = "Microsoft365.Audit.General"
-LogTypeMicrosoft365DLPAll = "Microsoft365.DLP.All"
 LogTypeMicrosoft365AuditAzureActiveDirectory = "Microsoft365.Audit.AzureActiveDirectory"
+LogTypeMicrosoft365AuditExchange = "Microsoft365.Audit.Exchange"
+LogTypeMicrosoft365AuditGeneral = "Microsoft365.Audit.General"
+LogTypeMicrosoft365AuditSharePoint = "Microsoft365.Audit.SharePoint"
+LogTypeMicrosoft365DLPAll = "Microsoft365.DLP.All"
 LogTypeMicrosoftGraphSecurityAlert = "MicrosoftGraph.SecurityAlert"
 LogTypeMongoDBOrganizationEvent = "MongoDB.OrganizationEvent"
 LogTypeMongoDBProjectEvent = "MongoDB.ProjectEvent"
 LogTypeNginxAccess = "Nginx.Access"
+LogTypeOSSECEventInfo = "OSSEC.EventInfo"
 LogTypeOktaSystemLog = "Okta.SystemLog"
 LogTypeOneLoginEvents = "OneLogin.Events"
 LogTypeOnePasswordItemUsage = "OnePassword.ItemUsage"
@@ -265,7 +330,7 @@ LogTypeOsqueryBatch = "Osquery.Batch"
 LogTypeOsqueryDifferential = "Osquery.Differential"
 LogTypeOsquerySnapshot = "Osquery.Snapshot"
 LogTypeOsqueryStatus = "Osquery.Status"
-LogTypeOSSECEventInfo = "OSSEC.EventInfo"
+LogTypePantherAudit = "Panther.Audit"
 LogTypeSalesforceLogin = "Salesforce.Login"
 LogTypeSalesforceLoginAs = "Salesforce.LoginAs"
 LogTypeSalesforceLogout = "Salesforce.Logout"
@@ -273,38 +338,45 @@ LogTypeSalesforceURI = "Salesforce.URI"
 LogTypeSentinelOneActivity = "SentinelOne.Activity"
 LogTypeSentinelOneDeepVisibility = "SentinelOne.DeepVisibility"
 LogTypeSentinelOneDeepVisibilityV2 = "SentinelOne.DeepVisibilityV2"
-LogTypeSlackAuditLogs = "Slack.AuditLogs"
 LogTypeSlackAccessLogs = "Slack.AccessLogs"
+LogTypeSlackAuditLogs = "Slack.AuditLogs"
 LogTypeSlackIntegrationLogs = "Slack.IntegrationLogs"
 LogTypeSnykGroupAudit = "Snyk.GroupAudit"
 LogTypeSnykOrgAudit = "Snyk.OrgAudit"
 LogTypeSophosCentral = "Sophos.Central"
-LogTypeSuricataDNS = "Suricata.DNS"
+LogTypeSuricataAlert = "Suricata.Alert"
 LogTypeSuricataAnomaly = "Suricata.Anomaly"
+LogTypeSuricataDHCP = "Suricata.DHCP"
+LogTypeSuricataDNS = "Suricata.DNS"
+LogTypeSuricataFileInfo = "Suricata.FileInfo"
+LogTypeSuricataFlow = "Suricata.Flow"
+LogTypeSuricataHTTP = "Suricata.HTTP"
+LogTypeSuricataSSH = "Suricata.SSH"
+LogTypeSuricataTLS = "Suricata.TLS"
 LogTypeSysdigAudit = "Sysdig.Audit"
-LogTypeSyslogRFC5424 = "Syslog.RFC5424"
 LogTypeSyslogRFC3164 = "Syslog.RFC3164"
-LogTypeGravitationalTeleportAudit = "Gravitational.TeleportAudit"
+LogTypeSyslogRFC5424 = "Syslog.RFC5424"
+LogTypeTorExitNode = "Tor.ExitNode"
 LogTypeWorkdayActivity = "Workday.Activity"
 LogTypeWorkdaySignOnAttempt = "Workday.SignOnAttempt"
-LogTypeZeekDNS = "Zeek.DNS"
 LogTypeZeekCaptureLoss = "Zeek.CaptureLoss"
 LogTypeZeekConn = "Zeek.Conn"
 LogTypeZeekDHCP = "Zeek.DHCP"
+LogTypeZeekDNS = "Zeek.DNS"
 LogTypeZeekDPD = "Zeek.DPD"
 LogTypeZeekFiles = "Zeek.Files"
 LogTypeZeekHTTP = "Zeek.HTTP"
-LogTypeZeekNotice = "Zeek.Notice"
 LogTypeZeekNTP = "Zeek.NTP"
+LogTypeZeekNotice = "Zeek.Notice"
 LogTypeZeekOCSP = "Zeek.OCSP"
 LogTypeZeekReporter = "Zeek.Reporter"
-LogTypeZeekSsh = "Zeek.Ssh"
 LogTypeZeekSoftware = "Zeek.Software"
-LogTypeZeekStats = "Zeek.Stats"
+LogTypeZeekSsh = "Zeek.Ssh"
 LogTypeZeekSsl = "Zeek.Ssl"
-LogTypeZeekX509 = "Zeek.X509"
+LogTypeZeekStats = "Zeek.Stats"
 LogTypeZeekTunnel = "Zeek.Tunnel"
 LogTypeZeekWeird = "Zeek.Weird"
+LogTypeZeekX509 = "Zeek.X509"
 LogTypeZendeskAudit = "Zendesk.Audit"
 LogTypeZoomActivity = "Zoom.Activity"
 LogTypeZoomOperation = "Zoom.Operation"
